package Bundle::CIPRES;

=head1 NAME

Bundle::CIPRES - CPAN Bundle for CIPRES prerequisites

=cut

our $VERSION = '0.01';

=head1 SYNOPSIS

cpan Bundle::CIPRES

=head1 CONTENTS

Class::Inspector

Log::Log4perl

Scalar::Util

Exception::Class

Test::More

Math::Random

IO::String

XML::Simple

SVG

Storable

Switch

=head1 AUTHOR

Rutger A. Vos, C<< <rvosa@sfu.ca> >>

=head1 COPYRIGHT & LICENSE

Copyright 2006 Rutger A. Vos, all rights reserved.

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1;